==> components-1.1.0.tgz: package/es/DropBox/DropBoxElement/props/propTypes.js <==
import PropTypes from 'prop-types';
export const DropBoxElementPropTypes = {
  animationStyle: PropTypes.oneOf(['default', 'bounce', 'fadeIn', 'scaleIn']),
  arrowBottom: PropTypes.number,
  arrowLeft: PropTypes.number,
  arrowPosition: PropTypes.oneOf(['start', 'mid', 'end']),
  arrowRight: PropTypes.number,
  arrowTop: PropTypes.number,
  bottom: PropTypes.number,
  boxPosition: PropTypes.oneOf(['bottomRight', 'bottomLeft', 'bottomCenter', 'topRight', 'topLeft', 'topCenter', 'rightTop', 'rightBottom', 'rightCenter', 'leftTop', 'leftBottom', 'leftCenter']),
  children: PropTypes.element,
  dataId: PropTypes.string,
  dataSelectorId: PropTypes.string,
  forwardRef: PropTypes.object,
  getRef: PropTypes.func,
  isAbsolutePositioningNeeded: PropTypes.bool,
  isActive: PropTypes.bool,
  isAnimate: PropTypes.bool,
  isArrow: PropTypes.bool,
  isBoxPaddingNeed: PropTypes.bool,
  isPadding: PropTypes.bool,
  isRadius: PropTypes.bool,
  left: PropTypes.number,
  onClick: PropTypes.func,
  right: PropTypes.number,
  size: PropTypes.oneOf(['mini', 'xmini', 'xsmall', 'small', 'medium', 'large', 'mlarge', 'xlarge', 'xxlarge', 'default']),
  top: PropTypes.number,
  tourId: PropTypes.string,
  htmlId: PropTypes.string,
  tabIndex: PropTypes.number,
  customClass: PropTypes.shape({
    customDropBox: PropTypes.string,
    customMobileDropBox: PropTypes.string,
    customDropBoxWrap: PropTypes.string,
    customMobileDropBoxWrap: PropTypes.string
  }),
  a11y: PropTypes.shape({
    role: PropTypes.string,
    ariaMultiselectable: PropTypes.bool,
    ariaLabelledby: PropTypes.string
  }),
  palette: PropTypes.oneOf(['default', 'dark']),
  customStyle: PropTypes.object,
  customInlineStyle: PropTypes.bool
};

==> components-1.2.14.tgz: package/es/DropBox/DropBoxElement/props/propTypes.js <==
import PropTypes from 'prop-types';
export const DropBoxElementPropTypes = {
  animationStyle: PropTypes.oneOf(['default', 'bounce', 'fadeIn', 'scaleIn']),
  arrowBottom: PropTypes.number,
  arrowLeft: PropTypes.number,
  arrowPosition: PropTypes.oneOf(['start', 'mid', 'end']),
  arrowRight: PropTypes.number,
  arrowTop: PropTypes.number,
  bottom: PropTypes.number,
  boxPosition: PropTypes.oneOf(['bottomRight', 'bottomLeft', 'bottomCenter', 'topRight', 'topLeft', 'topCenter', 'rightTop', 'rightBottom', 'rightCenter', 'leftTop', 'leftBottom', 'leftCenter']),
  children: PropTypes.element,
  dataId: PropTypes.string,
  dataSelectorId: PropTypes.string,
  forwardRef: PropTypes.object,
  getRef: PropTypes.func,
  isAbsolutePositioningNeeded: PropTypes.bool,
  isActive: PropTypes.bool,
  isAnimate: PropTypes.bool,
  isArrow: PropTypes.bool,
  isBoxPaddingNeed: PropTypes.bool,
  isPadding: PropTypes.bool,
  isRadius: PropTypes.bool,
  left: PropTypes.number,
  onClick: PropTypes.func,
  right: PropTypes.number,
  size: PropTypes.oneOf(['mini', 'xmini', 'xsmall', 'small', 'medium', 'large', 'mlarge', 'xlarge', 'xxlarge', 'default']),
  top: PropTypes.number,
  tourId: PropTypes.string,
  htmlId: PropTypes.string,
  tabIndex: PropTypes.number,
  customClass: PropTypes.shape({
    customDropBox: PropTypes.string,
    customMobileDropBox: PropTypes.string,
    customDropBoxWrap: PropTypes.string,
    customMobileDropBoxWrap: PropTypes.string
  }),
  a11y: PropTypes.shape({
    role: PropTypes.string,
    ariaMultiselectable: PropTypes.bool,
    ariaLabelledby: PropTypes.string
  }),
  palette: PropTypes.oneOf(['default', 'dark']),
  customStyle: PropTypes.object,
  customInlineStyle: PropTypes.bool,
  isModel: PropTypes.bool,
  direction: PropTypes.string,
  positionsOffset: PropTypes.object,
  targetOffset: PropTypes.object,
  zIndexStyle: PropTypes.object,
  subContainerRef: PropTypes.func
};
